Exception: APIKeyNotSet
- Inherits:
-
StandardError
- Object
- StandardError
- APIKeyNotSet
- Defined in:
- lib/octopart-ruby.rb
Overview
APIKeyNotSet is called when a client is instantiated without an api_key
APIKeyNotSet is called when a client is instantiated without an api_key